@@ -12,6 +12,7 @@ import org.apache.lucene.index.Term;
 import org.apache.lucene.search.Filter;
 import org.apache.lucene.search.HitCollector;
 import org.apache.lucene.search.Query;
+import org.apache.lucene.search.Weight;
 import org.apache.lucene.search.Searcher;
 import org.apache.lucene.search.TopDocs;
 import org.apache.lucene.search.Explanation;
@@ -57,15 +58,24 @@ public class ManagedSearcher extends Searcher {
         return m_searcher.doc(i);
     }
 
-    public void search(Query query, Filter filter, HitCollector results) throws IOException {
-        m_searcher.search(query, filter, results);
-    }
     public TopDocs search(Query query, Filter filter, int n) throws IOException {
         return m_searcher.search(query, filter, n);
     }
+    public TopDocs search(Weight weight, Filter filter, int doc) throws IOException {
+        return m_searcher.search(weight, filter, doc);
+    }
+    public void search(Query query, Filter filter, HitCollector results) throws IOException {
+        m_searcher.search(query, filter, results);
+    }
+    public void search(Weight weight, Filter filter, HitCollector results) throws IOException {
+        m_searcher.search(weight, filter, results);
+    }
     public TopFieldDocs search(Query query, Filter filter, int n, Sort sort) throws IOException {
         return m_searcher.search(query, filter, n, sort);
     }
+    public TopFieldDocs search(Weight weight, Filter filter, int n, Sort sort) throws IOException {
+        return m_searcher.search(weight, filter, n, sort);
+    }
     
     public int docFreq(Term term) throws IOException {
         return m_searcher.docFreq(term);
@@ -76,10 +86,13 @@ public class ManagedSearcher extends Searcher {
     }
 
 	public Query rewrite(Query original) throws IOException {
-	  return m_searcher.rewrite(original);
+	    return m_searcher.rewrite(original);
 	}
 
 	public Explanation explain(Query query, int doc) throws IOException {
-	  return m_searcher.explain(query, doc);
+	    return m_searcher.explain(query, doc);
 	}       
+    public Explanation explain(Weight weight, int doc) throws IOException {
+        return m_searcher.explain(weight, doc);
+    }       
 }
